# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Test POD files for correctness
Name:		perl-Test-Pod
Version:	1.52
Release:	16.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Pod
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Pod-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Pod::Simple) >= 3.05
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Test::Builder::Tester) >= 1.02
BuildRequires:	perl(Test::More) >= 0.62
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(File::Find)
Requires:	perl(File::Spec)
Requires:	perl(Pod::Simple) >= 3.05

# Remove under-specified dependencies
%global __requires_exclude ^perl\\(Pod::Simple\\)$

%description
Check POD files for errors or warnings in a test file, using Pod::Simple to do
the heavy lifting.

%prep
%setup -q -n Test-Pod-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README
%{perl_vendorlib}/Test/Pod.pm
%{_mandir}/man3/Test::Pod.3*

%changelog
* Tue Jun 27 2023 Paul Howarth <paul@city-fan.org> - 1.52-16
- Use SPDX-format license tag
- Switch upstream from search.cpan,org to metacpan.org

* Fri Apr 20 2018 Paul Howarth <paul@city-fan.org> - 1.52-1
- Update to 1.52
  - *.psgi files are now recognized as pod-containing files
  - Explicit perl 5.8 dependency removed

* Fri Apr  6 2018 Paul Howarth <paul@city-fan.org> - 1.51-8
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Wed Oct  5 2016 Paul Howarth <paul@city-fan.org> - 1.51-4
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Jul  6 2015 Paul Howarth <paul@city-fan.org> - 1.51-1
- Update to 1.51
  - Convert tooling from Module::Build to ExtUtils::MakeMaker (resolves
    circular dependency with MB on perl 5.21+)
- This release by ETHER → update source URL

* Tue Jun 16 2015 Paul Howarth <paul@city-fan.org> - 1.50-2
- Perl 5.22 rebuild

* Fri May 29 2015 Paul Howarth <paul@city-fan.org> - 1.50-1
- Update to 1.50
  - Restored support for ignoring directories listed in
    %%Test::Pod::ignore_dirs, inadvertently dropped by the switch to
    File::Find in v1.46 (GH#9)

* Wed May 13 2015 Paul Howarth <paul@city-fan.org> - 1.49-1
- Update to 1.49
  - Changed license in the README to "Same as Perl" to match the license listed
    in 'META.yml', and in the POD as of v1.42
  - Tightened up the heuristic for matching Perl batch files to require that
    the file end in '.bat', as described in the documentation
  - Simplified some of the matching code
  - Transferred ownership of the repository to the perl-pod organization on
    GitHub
  - Removed the Pod testing test from the distribution
- Classify buildreqs by usage
- Drop %%defattr, redundant since rpm 4.4

* Mon Jul 15 2013 Paul Howarth <paul@city-fan.org> - 1.48-2
- Perl 5.18 rebuild

* Tue May  7 2013 Paul Howarth <paul@city-fan.org> - 1.48-1
- Update to 1.48
  - Fixed test failure with versions of Pod::Simple lower than 3.24

* Sun May  5 2013 Paul Howarth <paul@city-fan.org> - 1.47-1
- Update to 1.47
  - Fixed failing test on Pod::Simple 3.27 and higher

* Sun Feb 17 2013 Paul Howarth <paul@city-fan.org> - 1.46-1
- Update to 1.46
  - Fixed a crash when 'all_pod_files_ok()' finds no files to test
  - Switched from custom file searching code to File::Find
  - Fixed failing test on Pod::Simple 3.24
- BR: perl(File::Find)

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 1.45-5
- BR: perl(Test::Builder)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> - 1.45-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Mar  9 2011 Paul Howarth <paul@city-fan.org> - 1.45-1
- Update to 1.45
  - Removed Module::Build from `build_requires`

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1.44-3
- Rebuild for perl 5.12.1 in Rawhide

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> - 1.44-2
- Fix dist tag to work with RHEL6 Beta

* Mon Apr 26 2010 Paul Howarth <paul@city-fan.org> - 1.44-1
- Update to 1.44
  - Use Module::Build::Compat's "traditional" configuration
- Revert to traditional ExtUtils::MakeMaker flow

* Wed Apr 21 2010 Paul Howarth <paul@city-fan.org> - 1.43-1
- Update to 1.43
  - Loosen version requirements for Test::More and Pod::Simple
  - Add File::Spec to the list of prereqs
- Drop perl(Pod::Simple) version requirement to 3.05

* Wed Mar 10 2010 Paul Howarth <paul@city-fan.org> - 1.42-1
- Update to 1.42
  - Fixed invalid Pod link
  - Changed license to "Same as Perl"
  - Include README
  - Recognize '.bat' files as Perl files if they have "--*-Perl-*--" on line 1
  - "all_pod_files_ok()" now operates on directories as well as files
  - Files with no POD now have " (no pod)" added to test name
  - Updated documentation to note that ".PL" files are considered Perl files
  - "all_pod_files_ok()" now lets "pod_file_ok()" set the default test name

* Tue Jan 19 2010 Paul Howarth <paul@city-fan.org> - 1.41-1
- Update to 1.41 (don't complain about L<text|url>, no longer illegal)
- New upstream maintainer -> new source URL
- BR: perl(Module::Build) rather than perl(ExtUtils::MakeMaker)
- Use Module::Build flow
- Dist tag for Rawhide no longer needs special-casing

* Mon Jul 13 2009 Paul Howarth <paul@city-fan.org> - 1.40-1
- Update to 1.40
  - Test::Pod now complains about the illegal construct L<text|url>
  - Many more ignored directories for various SCM systems
- Bump Pod::Simple version requirement to 3.07
- License changed to Artistic 2.0 or GPLv2
- Define RPM macros in global scope

* Tue Sep  2 2008 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
- Add buildreq perl(File::Spec)
- Tweak dist tag macros to work on current Rawhide with three-part releasenum

* Sun Mar 18 2007 Paul Howarth <paul@city-fan.org> - 1.20-3
- Fix dist tag for development releases and Fedora 7 onwards
- Remove %%{__perl_version} macro, used only once
- Remove %%{__perl_package} macro, used only twice
- Remove buildroot unconditionally in %%clean and %%install
- Don't use macros in command paths, hardcode them instead
- Fix argument order for find with -depth
- Use search.cpan.org download URL
- BuildRequire perl(ExtUtils::MakeMaker)
- Define %%{__id_u} in a more portable way
- No need to define %%{perl_vendorarch} in a noarch package
- No need to specify compiler optimization flags in a noarch package

* Thu Jun 23 2005 Paul Howarth <paul@city-fan.org> - 1.20-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20
- Tidy up spec file

* Mon May 10 2004 Paul Howarth <paul@city-fan.org> - 1.16-1
- Initial build
